@@ -30,7 +30,7 @@ krscvNOMAD <- function(xz,
                        initial.mesh.size.integer="1",
                        min.mesh.size.real=paste("r",sqrt(.Machine$double.eps),sep=""),
                        min.mesh.size.integer="1", 
-                       min.poll.size.real=paste("r",sqrt(.Machine$double.eps),sep=""),
+                       min.poll.size.real="1",
                        min.poll.size.integer="1", 
                        opts=list(),
                        nmulti=0,
