@@ -42,11 +42,11 @@ SGTELIB::Matrix::Matrix ( const std::string & name ,
 
   int i , j;
 
-  _X = new double * [_nbRows];
+  X0 = new double * [_nbRows];
   for ( i = 0 ; i < _nbRows ; ++i ) {
-    _X[i] = new double [_nbCols];
+    X0[i] = new double [_nbCols];
     for ( j = 0 ; j < _nbCols ; ++j )
-      _X[i][j] = 0.0;
+      X0[i][j] = 0.0;
   }
 }//
 
@@ -68,11 +68,11 @@ SGTELIB::Matrix::Matrix ( const std::string & name ,
 
   int i , j;
 
-  _X = new double * [_nbRows];
+  X0 = new double * [_nbRows];
   for ( i = 0 ; i < _nbRows ; ++i ) {
-    _X[i] = new double [_nbCols];
+    X0[i] = new double [_nbCols];
     for ( j = 0 ; j < _nbCols ; ++j )
-      _X[i][j] = A[i][j];
+      X0[i][j] = A[i][j];
   }
 }//
 
@@ -83,7 +83,7 @@ SGTELIB::Matrix::Matrix ( const std::string & file_name ) :
                   _name ( "no_name" ) ,
                   _nbRows    ( 0         ) ,
                   _nbCols    ( 0         ) ,
-                  _X    ( NULL      )   {
+                  X0    ( NULL      )   {
   *this = import_data(file_name);
 }//
 
@@ -95,7 +95,7 @@ SGTELIB::Matrix::Matrix (void) :
                _name ( "" ) ,
                _nbRows    ( 0   ) ,
                _nbCols    ( 0   ) {
-  _X = new double * [0];
+  X0 = new double * [0];
 }//
 
 /*---------------------------*/
@@ -106,11 +106,11 @@ SGTELIB::Matrix::Matrix ( const SGTELIB::Matrix & A ) :
                           _nbRows    ( A._nbRows    ) ,
                           _nbCols    ( A._nbCols    ) {
   int i , j;
-  _X = new double * [_nbRows];
+  X0 = new double * [_nbRows];
   for ( i = 0 ; i < _nbRows ; ++i ) {
-    _X[i] = new double [_nbCols];
+    X0[i] = new double [_nbCols];
     for ( j = 0 ; j < _nbCols ; ++j )
-      _X[i][j] = A._X[i][j];
+      X0[i][j] = A.X0[i][j];
   }
 }//
 
@@ -130,23 +130,23 @@ SGTELIB::Matrix & SGTELIB::Matrix::operator = ( const SGTELIB::Matrix & A ) {
   if ( _nbRows != A._nbRows || _nbCols != A._nbCols ) {
 
     for ( i = 0 ; i < _nbRows ; ++i )
-      delete [] _X[i];
-    delete [] _X;
+      delete [] X0[i];
+    delete [] X0;
 
     _nbRows = A._nbRows;
     _nbCols = A._nbCols;
 
-    _X = new double * [_nbRows];
+    X0 = new double * [_nbRows];
     for ( i = 0 ; i < _nbRows ; ++i ) {
-      _X[i] = new double [_nbCols];
+      X0[i] = new double [_nbCols];
       for ( j = 0 ; j < _nbCols ; ++j )
-        _X[i][j] = A._X[i][j];
+        X0[i][j] = A.X0[i][j];
     }
   }
   else {
     for ( i = 0 ; i < _nbRows ; ++i )
       for ( j = 0 ; j < _nbCols ; ++j )
-        _X[i][j] = A._X[i][j];
+        X0[i][j] = A.X0[i][j];
   }
     
   _name = A._name;
@@ -244,7 +244,7 @@ SGTELIB::Matrix SGTELIB::Matrix::string_to_row  ( const std::string & s , int nb
   double v;
   std::stringstream ss( s );
   int i=0;
-  while( ss >> v ) row._X[0][i++] = v;
+  while( ss >> v ) row.X0[0][i++] = v;
   if (i++!=nbCols){
     SGTELIB::rout << "In line \"" << s << "\"\n";
     SGTELIB::rout << "Found " << i << " components\n";
@@ -329,8 +329,8 @@ SGTELIB::Matrix::~Matrix ( void ) {
   //SGTELIB::rout << "Delete " << _name << "\n";
   SGTELIB::rout.flush();
   for ( int i = 0 ; i < _nbRows ; ++i )
-    delete [] _X[i];
-  delete [] _X;
+    delete [] X0[i];
+  delete [] X0;
 }//
 
 /*---------------------------*/
@@ -338,17 +338,17 @@ SGTELIB::Matrix::~Matrix ( void ) {
 /*---------------------------*/
 void SGTELIB::Matrix::add_row  ( const double * row ) {
 
-  double ** new_X = new double * [_nbRows+1];
+  double ** newX0 = new double * [_nbRows+1];
 
   for ( int i = 0 ; i < _nbRows ; ++i )
-    new_X[i] = _X[i];
+    newX0[i] = X0[i];
 
-  new_X[_nbRows] = new double [_nbCols];
+  newX0[_nbRows] = new double [_nbCols];
   for ( int j = 0 ; j < _nbCols ; ++j )
-    new_X[_nbRows][j] = row[j];
+    newX0[_nbRows][j] = row[j];
   
-  delete [] _X;
-  _X = new_X;
+  delete [] X0;
+  X0 = newX0;
   ++_nbRows;
 }//
 
@@ -364,19 +364,19 @@ void SGTELIB::Matrix::add_rows ( const Matrix & A ) {
   int i , j;
   int new_nbRows = _nbRows + A._nbRows;
 
-  double ** new_X = new double * [new_nbRows];
+  double ** newX0 = new double * [new_nbRows];
 
   for ( i = 0 ; i < _nbRows ; ++i )
-    new_X[i] = _X[i];
+    newX0[i] = X0[i];
 
   for ( i = _nbRows ; i < new_nbRows ; ++i ) {
-    new_X[i] = new double [_nbCols];
+    newX0[i] = new double [_nbCols];
     for ( j = 0 ; j < _nbCols ; ++j )
-      new_X[i][j] = A._X[i-_nbRows][j];
+      newX0[i][j] = A.X0[i-_nbRows][j];
   }
 
-  delete [] _X;
-  _X = new_X;
+  delete [] X0;
+  X0 = newX0;
   _nbRows = new_nbRows;
 }//
 
@@ -398,14 +398,14 @@ void SGTELIB::Matrix::add_cols ( const Matrix & A ) {
     x = new double [new_nbCols];
     // Original columns
     for ( j = 0 ; j < _nbCols ; ++j )
-      x[j] = _X[i][j];
+      x[j] = X0[i][j];
     // Additional columns
     for ( j = _nbCols ; j < new_nbCols ; ++j )
-      x[j] = A._X[i][j-_nbCols];
+      x[j] = A.X0[i][j-_nbCols];
     // Remove original line
-    delete [] _X[i];
+    delete [] X0[i];
     // Put new line
-    _X[i] = x;
+    X0[i] = x;
   }
 
   _nbCols = new_nbCols;
@@ -419,20 +419,20 @@ void SGTELIB::Matrix::add_rows ( const int p ) {
   int i , j;
   int new_nbRows = _nbRows + p;
 
-  double ** new_X = new double * [new_nbRows];
+  double ** newX0 = new double * [new_nbRows];
 
   for ( i = 0 ; i < _nbRows ; ++i )
-    new_X[i] = _X[i];
+    newX0[i] = X0[i];
 
   for ( i = _nbRows ; i < new_nbRows ; ++i ) {
-    new_X[i] = new double [_nbCols];
+    newX0[i] = new double [_nbCols];
     for ( j = 0 ; j < _nbCols ; ++j )
-      new_X[i][j] = 0.0;
+      newX0[i][j] = 0.0;
   }
 
-  delete [] _X;
+  delete [] X0;
 
-  _X = new_X;
+  X0 = newX0;
   _nbRows = new_nbRows;
 }//
 
@@ -444,16 +444,16 @@ void SGTELIB::Matrix::remove_rows ( const int p ) {
   int i;
   int new_nbRows = _nbRows - p;
 
-  double ** new_X = new double * [new_nbRows];
+  double ** newX0 = new double * [new_nbRows];
 
   for ( i = 0 ; i < new_nbRows ; ++i )
-    new_X[i] = _X[i];
+    newX0[i] = X0[i];
 
   for ( i = new_nbRows ; i < _nbRows ; ++i )
-    delete [] _X[i];
+    delete [] X0[i];
 
-  delete [] _X;
-  _X = new_X;
+  delete [] X0;
+  X0 = newX0;
   _nbRows = new_nbRows;
 }//
 
@@ -470,11 +470,11 @@ void SGTELIB::Matrix::add_cols ( const int p ) {
   for ( i = 0 ; i < _nbRows ; ++i ) {
     x = new double [new_nbCols];
     for ( j = 0 ; j < _nbCols ; ++j )
-      x[j] = _X[i][j];
+      x[j] = X0[i][j];
     for ( j = _nbCols ; j < new_nbCols ; ++j )
       x[j] = 0.0;
-    delete [] _X[i];
-    _X[i] = x;
+    delete [] X0[i];
+    X0[i] = x;
   }
 
   _nbCols = new_nbCols;
@@ -499,7 +499,7 @@ bool SGTELIB::Matrix::is_sym ( void ) const {
   int i,j;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = i+1 ; j < _nbCols ; ++j ) {
-      if (_X[i][j]!=_X[j][i]){
+      if (X0[i][j]!=X0[j][i]){
         return false;
       }
     }
@@ -515,9 +515,9 @@ void SGTELIB::Matrix::set_random ( double l , double u , bool round ) {
   int i , j;
   for ( i = 0 ; i < _nbRows ; ++i ){
     for ( j = 0 ; j < _nbCols ; ++j ){
-      _X[i][j] = l + (u-l) * SGTELIB::uniform_rand();
+      X0[i][j] = l + (u-l) * SGTELIB::uniform_rand();
       if ( round )
-        _X[i][j] = SGTELIB::round ( _X[i][j] );
+        X0[i][j] = SGTELIB::round ( X0[i][j] );
     }
   }
 }//
@@ -529,7 +529,7 @@ void SGTELIB::Matrix::fill ( double v ) {
   int i , j;
   for ( i = 0 ; i < _nbRows ; ++i ){
     for ( j = 0 ; j < _nbCols ; ++j ){
-      _X[i][j] = v;
+      X0[i][j] = v;
     }
   }
 }//
@@ -546,7 +546,7 @@ void SGTELIB::Matrix::set ( const int i , const int j , const double d ) {
       throw SGTELIB::Exception ( __FILE__ , __LINE__ , "Matrix::set(i,j): bad index" );
     }
   #endif
-  _X[i][j] = d;
+  X0[i][j] = d;
 }//
 
 void SGTELIB::Matrix::set_row (const SGTELIB::Matrix & T , const int i){
@@ -556,7 +556,7 @@ void SGTELIB::Matrix::set_row (const SGTELIB::Matrix & T , const int i){
     }
   #endif
   for (int j=0 ; j<_nbCols ; j++){
-    _X[i][j] = T.get(0,j);
+    X0[i][j] = T.get(0,j);
   }
 }//
 
@@ -567,7 +567,7 @@ void SGTELIB::Matrix::set_col (const SGTELIB::Matrix & T , const int j){
     }
   #endif
   for (int i=0 ; i<_nbRows ; i++){
-    _X[i][j] = T.get(i,0);
+    X0[i][j] = T.get(i,0);
   }
 }//
 
@@ -578,7 +578,7 @@ void SGTELIB::Matrix::set_row (const double v , const int i){
     }
   #endif
   for (int j=0 ; j<_nbCols ; j++){
-    _X[i][j] = v;
+    X0[i][j] = v;
   }
 }//
 
@@ -589,7 +589,7 @@ void SGTELIB::Matrix::set_col (const double v , const int j){
     }
   #endif
   for (int i=0 ; i<_nbRows ; i++){
-    _X[i][j] = v;
+    X0[i][j] = v;
   }
 }//
 
@@ -599,9 +599,9 @@ void SGTELIB::Matrix::permute (const int i1 , const int j1 , const int i2 , cons
       throw SGTELIB::Exception ( __FILE__ , __LINE__ , "Matrix::permut: bad index" );
     }
   #endif
-  double buffer = _X[i1][j1];
-  _X[i1][j1] = _X[i2][j2];
-  _X[i2][j2] = buffer;
+  double buffer = X0[i1][j1];
+  X0[i1][j1] = X0[i2][j2];
+  X0[i2][j2] = buffer;
 }//
 
 void SGTELIB::Matrix::multiply_row (const double v , const int i){
@@ -611,7 +611,7 @@ void SGTELIB::Matrix::multiply_row (const double v , const int i){
     }
   #endif
   for (int j=0 ; j<_nbCols ; j++){
-    _X[i][j] *= v;
+    X0[i][j] *= v;
   }
 }//
 
@@ -622,7 +622,7 @@ void SGTELIB::Matrix::multiply_col (const double v , const int j){
     }
   #endif
   for (int i=0 ; i<_nbRows ; i++){
-    _X[i][j] *= v;
+    X0[i][j] *= v;
   }
 }//
 
@@ -639,14 +639,14 @@ const double & SGTELIB::Matrix::operator [] ( int k ) const {
   if (_nbRows==1) j=k; 
   else if (_nbCols==1) i=k;
   else throw SGTELIB::Exception ( __FILE__ , __LINE__ , "Matrix::[k]: the matrix is not a vector" );
-  return _X[i][j];
+  return X0[i][j];
 }//
 double & SGTELIB::Matrix::operator [] ( int k ){
   int i = 0 , j = 0;
   if (_nbRows==1) j=k; 
   else if (_nbCols==1) i=k;
   else throw SGTELIB::Exception ( __FILE__ , __LINE__ , "Matrix::[k]: the matrix is not a vector" );
-  return _X[i][j];
+  return X0[i][j];
 }//
 
 /*---------------------------*/
@@ -660,7 +660,7 @@ double SGTELIB::Matrix::get ( const int i , const int j ) const {
       throw SGTELIB::Exception ( __FILE__ , __LINE__ , "Matrix::get(i,j): bad index" );
     }
   #endif
-  return _X[i][j];
+  return X0[i][j];
 }//
 
 /*------------------------------------------*/
@@ -680,7 +680,7 @@ SGTELIB::Matrix SGTELIB::Matrix::get_row (const int i) const {
   #endif
   SGTELIB::Matrix A (_name+"(i,:)",1,_nbCols);
   for (int j=0 ; j<_nbCols ; j++){
-    A._X[0][j] = _X[i][j];
+    A.X0[0][j] = X0[i][j];
   }
   return A;
 }//
@@ -695,7 +695,7 @@ SGTELIB::Matrix SGTELIB::Matrix::get_col (const int j) const {
   #endif
   SGTELIB::Matrix A (_name+"(:,j)",_nbRows,1);
   for (int i=0 ; i<_nbRows ; i++){
-    A._X[i][0] = _X[i][j];
+    A.X0[i][0] = X0[i][j];
   }
   return A;
 }//
@@ -803,7 +803,7 @@ SGTELIB::Matrix SGTELIB::Matrix::get_cols (const std::list<int> & list_cols) con
 int SGTELIB::Matrix::get_nb_diff_values ( int j ) const {
   std::set<double> s;
   for ( int i = 0 ; i < _nbRows ; ++i ){
-    s.insert ( _X[i][j] );
+    s.insert ( X0[i][j] );
   }
   return static_cast<int> ( s.size() );
 }//
@@ -816,7 +816,7 @@ void SGTELIB::Matrix::display ( std::ostream & out ) const {
   out << std::endl << _name << "=[\n";
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j )
-      out << "\t" << std::setw(10) << _X[i][j] << " ";
+      out << "\t" << std::setw(10) << X0[i][j] << " ";
     out << ";" << std::endl;
   }
   out << "];" << std::endl;
@@ -829,15 +829,15 @@ void SGTELIB::Matrix::display_short ( std::ostream & out ) const {
   if (get_numel()<5) display(out);
   else{
     out << std::endl << _name << " ( " << _nbRows << " x " << _nbCols << " ) =\n[";
-    out << "\t" << std::setw(10) << _X[0][0] << " ";
+    out << "\t" << std::setw(10) << X0[0][0] << " ";
     if (_nbCols>2) out << "... ";
-    out << "\t" << std::setw(10) << _X[0][_nbCols] << "\n";
+    out << "\t" << std::setw(10) << X0[0][_nbCols] << "\n";
     if (_nbRows>2) out << "\t       ...";
     if (_nbCols>2) out << "    ";
     if (_nbRows>2) out << "\t       ...\n";
-    out << "\t" << std::setw(10) << _X[_nbRows-1][0] << " ";
+    out << "\t" << std::setw(10) << X0[_nbRows-1][0] << " ";
     if (_nbCols>2) out << "... ";
-    out << "\t" << std::setw(10) << _X[_nbRows-1][_nbCols] << "]\n";
+    out << "\t" << std::setw(10) << X0[_nbRows-1][_nbCols] << "]\n";
   }
 }//
 
@@ -868,7 +868,7 @@ SGTELIB::Matrix SGTELIB::Matrix::col_vector ( const double * v,
   }  
   SGTELIB::Matrix V("V",n,1);
   for (int i=0 ; i<n ; i++){
-    V._X[i][0] = v[i];
+    V.X0[i][0] = v[i];
   }
   return V;
 }//
@@ -883,7 +883,7 @@ SGTELIB::Matrix SGTELIB::Matrix::row_vector ( const double * v,
   }  
   SGTELIB::Matrix V("V",1,n);
   for (int i=0 ; i<n ; i++){
-    V._X[0][i] = v[i];
+    V.X0[0][i] = v[i];
   }
   return V;
 }//
@@ -911,9 +911,9 @@ SGTELIB::Matrix SGTELIB::Matrix::product ( const SGTELIB::Matrix & A,
   //double v;
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      C._X[i][j] = 0;
+      C.X0[i][j] = 0;
       for ( k = 0 ; k < nb_inter; ++k ){
-        C._X[i][j] += A._X[i][k]*B._X[k][j];
+        C.X0[i][j] += A.X0[i][k]*B.X0[k][j];
       }
     }
   }
@@ -984,7 +984,7 @@ SGTELIB::Matrix SGTELIB::Matrix::subset_product (const SGTELIB::Matrix & A,
   for (int i=0 ; i<p ; i++){
     for (int j=0 ; j<r ; j++){
       for (int k=0 ; k<q ; k++){
-        C._X[i][j] += A._X[i][k]*B._X[k][j];
+        C.X0[i][j] += A.X0[i][k]*B.X0[k][j];
       } 
     }
   }
@@ -1037,8 +1037,8 @@ SGTELIB::Matrix SGTELIB::Matrix::hadamard_square ( const SGTELIB::Matrix & A )
   double a;
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      a = A._X[i][j];
-      C._X[i][j] = a*a;
+      a = A.X0[i][j];
+      C.X0[i][j] = a*a;
     }
   }
   return C;
@@ -1055,7 +1055,7 @@ void SGTELIB::Matrix::hadamard_square ( void )  {
   int i,j;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j ){
-      _X[i][j] *= _X[i][j];
+      X0[i][j] *= X0[i][j];
     }
   }
 }//
@@ -1071,7 +1071,7 @@ void SGTELIB::Matrix::hadamard_inverse ( void )  {
   int i,j;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j ){
-      _X[i][j] = 1/_X[i][j];
+      X0[i][j] = 1/X0[i][j];
     }
   }
 }//
@@ -1091,7 +1091,7 @@ SGTELIB::Matrix SGTELIB::Matrix::hadamard_sqrt ( const SGTELIB::Matrix & A )  {
   int i,j;
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      C._X[i][j] = sqrt(fabs(A._X[i][j]));
+      C.X0[i][j] = sqrt(fabs(A.X0[i][j]));
     }
   }
   return C;
@@ -1114,7 +1114,7 @@ SGTELIB::Matrix SGTELIB::Matrix::hadamard_power ( const SGTELIB::Matrix & A , co
   int i,j;
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      C._X[i][j] = pow(A._X[i][j],e);
+      C.X0[i][j] = pow(A.X0[i][j],e);
     }
   }
   return C;
@@ -1131,7 +1131,7 @@ void SGTELIB::Matrix::hadamard_sqrt ( void )  {
   int i,j;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j ){
-      _X[i][j] = sqrt(fabs(_X[i][j]));
+      X0[i][j] = sqrt(fabs(X0[i][j]));
     }
   }
 }//
@@ -1157,9 +1157,9 @@ SGTELIB::Matrix SGTELIB::Matrix::diagA_product ( const SGTELIB::Matrix & A,
   if ( (na==ma) || (ma==n) ){
     // A is square, use the diag terms
     for ( i = 0 ; i < n ; i++ ) {
-      Aii = A._X[i][i];
+      Aii = A.X0[i][i];
       for ( j = 0 ; j < m ; j++ ) {
-        C._X[i][j] = Aii*B._X[i][j];
+        C.X0[i][j] = Aii*B.X0[i][j];
       }
     }
     return C;
@@ -1167,9 +1167,9 @@ SGTELIB::Matrix SGTELIB::Matrix::diagA_product ( const SGTELIB::Matrix & A,
   else if ( (na==1) && (ma==n) ){
     // A is a line vector
     for ( i = 0 ; i < n ; i++ ) {
-      Aii = A._X[0][i];
+      Aii = A.X0[0][i];
       for ( j = 0 ; j < m ; j++ ) {
-        C._X[i][j] = Aii*B._X[i][j];
+        C.X0[i][j] = Aii*B.X0[i][j];
       }
     }
     return C;
@@ -1177,9 +1177,9 @@ SGTELIB::Matrix SGTELIB::Matrix::diagA_product ( const SGTELIB::Matrix & A,
   else if ( (na==n) && (ma==1) ){
     // A is a col vector
     for ( i = 0 ; i < n ; i++ ) {
-      Aii = A._X[i][0];
+      Aii = A.X0[i][0];
       for ( j = 0 ; j < m ; j++ ) {
-        C._X[i][j] = Aii*B._X[i][j];
+        C.X0[i][j] = Aii*B.X0[i][j];
       }
     }
     return C;
@@ -1213,9 +1213,9 @@ SGTELIB::Matrix SGTELIB::Matrix::diagB_product ( const SGTELIB::Matrix & A,
   if ( (nb==mb) && (mb==n) ){
     // B is square, use the diag terms
     for ( j = 0 ; j < m ; j++ ) {
-      Bjj = B._X[j][j];
+      Bjj = B.X0[j][j];
       for ( i = 0 ; i < n ; i++ ) {
-        C._X[i][j] = A._X[i][j]*Bjj;
+        C.X0[i][j] = A.X0[i][j]*Bjj;
       }
     }
     return C;
@@ -1223,9 +1223,9 @@ SGTELIB::Matrix SGTELIB::Matrix::diagB_product ( const SGTELIB::Matrix & A,
   else if ( (nb==1) && (mb==m) ){
     // B is a line vector
     for ( j = 0 ; j < m ; j++ ) {
-      Bjj = B._X[0][j];
+      Bjj = B.X0[0][j];
       for ( i = 0 ; i < n ; i++ ) {
-        C._X[i][j] = A._X[i][j]*Bjj;
+        C.X0[i][j] = A.X0[i][j]*Bjj;
       }
     }
     return C;
@@ -1233,9 +1233,9 @@ SGTELIB::Matrix SGTELIB::Matrix::diagB_product ( const SGTELIB::Matrix & A,
   else if ( (nb==m) && (mb==1) ){
     // B is a col vector
     for ( j = 0 ; j < m ; j++ ) {
-      Bjj = B._X[j][0];
+      Bjj = B.X0[j][0];
       for ( i = 0 ; i < n ; i++ ) {
-        C._X[i][j] = A._X[i][j]*Bjj;
+        C.X0[i][j] = A.X0[i][j]*Bjj;
       }
     }
     return C;
@@ -1270,9 +1270,9 @@ SGTELIB::Matrix SGTELIB::Matrix::transposeA_product ( const SGTELIB::Matrix & A,
   //double v;
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      C._X[i][j] = 0;
+      C.X0[i][j] = 0;
       for ( k = 0 ; k < nb_inter; ++k ){
-        C._X[i][j] += A._X[k][i]*B._X[k][j];
+        C.X0[i][j] += A.X0[k][i]*B.X0[k][j];
       }
     }
   }
@@ -1343,7 +1343,7 @@ SGTELIB::Matrix SGTELIB::Matrix::get_matrix_dPiPZs ( const SGTELIB::Matrix & Ai,
   int i,j;
   for ( i = 0 ; i < p ; i++ ) {
     v = 0;
-    for ( j = 0 ; j < q ; j++) v += HAi._X[i][j]*H._X[i][j];
+    for ( j = 0 ; j < q ; j++) v += HAi.X0[i][j]*H.X0[i][j];
     v = 1.0/( 1.0 - v );
     dPiPZs.multiply_row ( v , i );
   }
@@ -1371,7 +1371,7 @@ SGTELIB::Matrix SGTELIB::Matrix::get_matrix_dPiPZs ( const SGTELIB::Matrix & Ai,
   int i,j;
   for ( i = 0 ; i < p ; i++ ) {
     v = 0;
-    for ( j = 0 ; j < q ; j++) v += HAi._X[i][j]*H._X[i][j];
+    for ( j = 0 ; j < q ; j++) v += HAi.X0[i][j]*H.X0[i][j];
     v = 1.0/( 1.0 - v );
     dPiPZs.multiply_row ( v , i );
   }
@@ -1425,7 +1425,7 @@ SGTELIB::Matrix SGTELIB::Matrix::add ( const SGTELIB::Matrix & A,
   int i,j;
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      C._X[i][j] = A._X[i][j]+B._X[i][j];
+      C.X0[i][j] = A.X0[i][j]+B.X0[i][j];
     }
   }
   return C;
@@ -1447,7 +1447,7 @@ void SGTELIB::Matrix::add ( const SGTELIB::Matrix & B ) {
   int i,j;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j ){
-      _X[i][j] += B.get(i,j);
+      X0[i][j] += B.get(i,j);
     }
   }
 }//
@@ -1468,12 +1468,12 @@ SGTELIB::Matrix SGTELIB::Matrix::add_fill ( const SGTELIB::Matrix & A,
   int i,j;
   for ( i = 0 ; i < A.get_nb_rows() ; ++i ) {
     for ( j = 0 ; j < A.get_nb_cols() ; ++j ){
-      C._X[i][j] = A._X[i][j];
+      C.X0[i][j] = A.X0[i][j];
     }
   }
   for ( i = 0 ; i < B.get_nb_rows() ; ++i ) {
     for ( j = 0 ; j < B.get_nb_cols() ; ++j ){
-      C._X[i][j] += B._X[i][j];
+      C.X0[i][j] += B.X0[i][j];
     }
   }
   return C;
@@ -1526,7 +1526,7 @@ void SGTELIB::Matrix::sub ( const SGTELIB::Matrix & B ) {
   int i,j;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j ){
-      _X[i][j] -= B._X[i][j];
+      X0[i][j] -= B.X0[i][j];
     }
   }
 }//
@@ -1605,9 +1605,9 @@ SGTELIB::Matrix SGTELIB::Matrix::rank ( void ) const {
     for (i=0 ; i<m ; i++){
       dmin = +INF;
       for (j=0 ; j<m ; j++){
-        if (D._X[0][j]<dmin){
+        if (D.X0[0][j]<dmin){
           jmin = j;
-          dmin = D._X[0][j];
+          dmin = D.X0[0][j];
         }
       }
       R.set(0,jmin,double(i));
@@ -1641,7 +1641,7 @@ double SGTELIB::Matrix::rmse ( void ) const{
   double xij;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j ){
-      xij = _X[i][j];
+      xij = X0[i][j];
       v += xij*xij;
     }
   }
@@ -1660,7 +1660,7 @@ double SGTELIB::Matrix::normsquare ( void ) const{
   double xij;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j ){
-      xij = _X[i][j];
+      xij = X0[i][j];
       v += xij*xij;
     }
   }
@@ -1679,15 +1679,15 @@ void SGTELIB::Matrix::normalize_cols ( void ){
     d = 0;
 
     for ( i = 0 ; i < _nbRows ; ++i )
-      d += _X[i][j];
+      d += X0[i][j];
 
     if (d==0){
       for ( i = 0 ; i < _nbRows ; ++i )
-        _X[i][j] = 1/_nbRows;
+        X0[i][j] = 1/_nbRows;
     }
     else{
       for ( i = 0 ; i < _nbRows ; ++i )
-        _X[i][j] /= d;
+        X0[i][j] /= d;
     }
   }
 }//
@@ -1711,7 +1711,7 @@ double SGTELIB::Matrix::sum ( void ) const{
   int i,j;
   for ( i = 0 ; i < _nbRows ; ++i ) {
     for ( j = 0 ; j < _nbCols ; ++j ){
-      v += _X[i][j];
+      v += X0[i][j];
     }
   }
   return v;
@@ -1733,9 +1733,9 @@ SGTELIB::Matrix SGTELIB::Matrix::sum ( const int direction ) const{
     for ( j = 0 ; j < _nbCols ; ++j ){
       v = 0;
       for ( i = 0 ; i < _nbRows ; ++i ) {
-        v += _X[i][j];
+        v += X0[i][j];
       }
-      S._X[0][j] = v;
+      S.X0[0][j] = v;
     }
     return S;
   }
@@ -1744,9 +1744,9 @@ SGTELIB::Matrix SGTELIB::Matrix::sum ( const int direction ) const{
     for ( i = 0 ; i < _nbRows ; ++i ) {
       v = 0;
       for ( j = 0 ; j < _nbCols ; ++j ){
-        v += _X[i][j];
+        v += X0[i][j];
       }
-      S._X[i][0] = v;
+      S.X0[i][0] = v;
     }
     return S;
   }
@@ -1776,7 +1776,7 @@ int SGTELIB::Matrix::count ( void ) const{
   const int nb_cols = get_nb_cols();
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      v += (fabs(_X[i][j])>EPSILON)? 1:0 ;
+      v += (fabs(X0[i][j])>EPSILON)? 1:0 ;
     }
   }
   return v;
@@ -1827,7 +1827,7 @@ SGTELIB::Matrix SGTELIB::Matrix::conjugate_solve ( const SGTELIB::Matrix & A ,
   while (iter < 100){
     Ap = A*p;
     pAp = 0;
-    for (int i=0 ; i<n ; i++) pAp += p._X[i][0]*Ap._X[i][0];
+    for (int i=0 ; i<n ; i++) pAp += p.X0[i][0]*Ap.X0[i][0];
     alpha = rr/pAp;
     x = x+alpha*p;
     rr_old = rr;
@@ -1863,11 +1863,11 @@ SGTELIB::Matrix SGTELIB::Matrix::cholesky ( void ) const {
     for (j = 0; j < (i+1); j++) {
       s = 0;
       for (k = 0; k < j; k++){
-        s += L._X[i][k] * L._X[j][k];
+        s += L.X0[i][k] * L.X0[j][k];
       }
-      L._X[i][j] = (i == j) ?
-         sqrt(_X[i][i] - s) :
-         (1.0 / L._X[j][j] * (_X[i][j] - s));
+      L.X0[i][j] = (i == j) ?
+         sqrt(X0[i][i] - s) :
+         (1.0 / L.X0[j][j] * (X0[i][j] - s));
     }
   }
   return L;
@@ -1895,17 +1895,17 @@ SGTELIB::Matrix SGTELIB::Matrix::cholesky_inverse ( double * det ) const {
   int i,j,k,kmin;
   for (i=0 ; i<n ; i++){
     for (j=0 ; j<n ; j++){
-      A._X[i][j] = 0;
+      A.X0[i][j] = 0;
       kmin = std::max(i,j);
       for (k=kmin ; k<n ; k++){
-          A._X[i][j] += Li._X[k][i]*Li._X[k][j];
+          A.X0[i][j] += Li.X0[k][i]*Li.X0[k][j];
       }
     }
   }
 
   if (det){
     double v = 1;
-    for (i=0 ; i<n ; i++) v *= L._X[i][i];
+    for (i=0 ; i<n ; i++) v *= L.X0[i][i];
     v *= v;
     if ( isnan(v)) v=+INF;
     *det = v;
@@ -1937,9 +1937,9 @@ SGTELIB::Matrix SGTELIB::Matrix::triu_solve( const SGTELIB::Matrix & U ,
 
   for (int i=n-1 ; i>=0 ; i--){
     for (int j=i+1 ; j<n ; j++){
-      x._X[i][0] -= U._X[i][j]*x._X[j][0];
+      x.X0[i][0] -= U.X0[i][j]*x.X0[j][0];
     }
-    x._X[i][0] /= U._X[i][i];
+    x.X0[i][0] /= U.X0[i][i];
   }
 
   return x;
@@ -1985,9 +1985,9 @@ SGTELIB::Matrix SGTELIB::Matrix::tril_solve( const SGTELIB::Matrix & L ,
 
   for (int i=0 ; i<n ; i++){
     for (int j=0 ; j<i ; j++){
-      x._X[i][0] -= L._X[i][j]*x._X[j][0];
+      x.X0[i][0] -= L.X0[i][j]*x.X0[j][0];
     }
-    x._X[i][0] /= L._X[i][i];
+    x.X0[i][0] /= L.X0[i][i];
   }
 
   return x;
@@ -2044,7 +2044,7 @@ SGTELIB::Matrix SGTELIB::Matrix::transpose ( void ) const{
   SGTELIB::Matrix A (_name+"'",_nbCols,_nbRows); 
   for (int i=0 ; i<_nbCols ; i++){
     for (int j=0 ; j<_nbRows ; j++){
-      A.set(i,j,_X[j][i]);
+      A.set(i,j,X0[j][i]);
     }
   }
   return A;
@@ -2058,7 +2058,7 @@ SGTELIB::Matrix SGTELIB::Matrix::diag ( void ) const{
   SGTELIB::Matrix A;
   if (_nbCols==_nbRows){
     A = SGTELIB::Matrix("A",_nbRows,1);   
-    for (int i=0 ; i<_nbCols ; i++) A.set(i,0,_X[i][i]);
+    for (int i=0 ; i<_nbCols ; i++) A.set(i,0,X0[i][i]);
   }
   else if ( (_nbCols==1) || (_nbRows==1) ){
     const int n=std::max(_nbCols,_nbRows);
@@ -2183,7 +2183,7 @@ bool SGTELIB::Matrix::SVD_decomposition ( std::string & error_msg ,
   // copy the current matrix into U:
   for ( i = 0 ; i < nbRows ; ++i )
     for ( j = 0 ; j < nbCols ; ++j )
-      U[i][j] = _X[i][j];
+      U[i][j] = X0[i][j];
 
   // Householder reduction to bidiagonal form:
   for ( i = 0 ; i < nbCols ; ++i ) {
@@ -2426,7 +2426,7 @@ bool SGTELIB::Matrix::has_nan ( void ) const {
   int i , j;
   for ( i = 0 ; i < _nbRows ; ++i ){
     for ( j = 0 ; j < _nbCols ; ++j ){
-      if ( isnan(_X[i][j])){
+      if ( isnan(X0[i][j])){
         return true;
       }
     }
@@ -2441,7 +2441,7 @@ bool SGTELIB::Matrix::has_inf ( void ) const {
   int i , j;
   for ( i = 0 ; i < _nbRows ; ++i ){
     for ( j = 0 ; j < _nbCols ; ++j ){
-      if ( isinf(_X[i][j])){
+      if ( isinf(X0[i][j])){
         return true;
       }
     }
@@ -2456,8 +2456,8 @@ void SGTELIB::Matrix::replace_nan ( double d ) {
   int i , j;
   for ( i = 0 ; i < _nbRows ; ++i ){
     for ( j = 0 ; j < _nbCols ; ++j ){
-      if ( isnan(_X[i][j])){
-        _X[i][j] = d;
+      if ( isnan(X0[i][j])){
+        X0[i][j] = d;
       }
     }
   }
@@ -2475,8 +2475,8 @@ int SGTELIB::Matrix::get_max_index (void ) {
   //   3 6
   for ( j = 0 ; j < _nbCols ; ++j ){
     for ( i = 0 ; i < _nbRows ; ++i ){
-      if (_X[i][j] > vmax){
-        vmax = _X[i][j];
+      if (X0[i][j] > vmax){
+        vmax = X0[i][j];
         kmax = k;
       }
       k++;
@@ -2493,7 +2493,7 @@ double SGTELIB::Matrix::min (void) {
   int i,j;
   for ( j = 0 ; j < _nbCols ; ++j ){
     for ( i = 0 ; i < _nbRows ; ++i ){
-      d = std::min(d,_X[i][j]);
+      d = std::min(d,X0[i][j]);
     }
   }
   return d;
@@ -2504,7 +2504,7 @@ double SGTELIB::Matrix::max (void) {
   int i,j;
   for ( j = 0 ; j < _nbCols ; ++j ){
     for ( i = 0 ; i < _nbRows ; ++i ){
-      d = std::max(d,_X[i][j]);
+      d = std::max(d,X0[i][j]);
     }
   }
   return d;
@@ -2532,7 +2532,7 @@ SGTELIB::Matrix SGTELIB::Matrix::max ( const SGTELIB::Matrix & A ,
   int i,j;
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      C._X[i][j] = std::max( A._X[i][j] , B._X[i][j] );
+      C.X0[i][j] = std::max( A.X0[i][j] , B.X0[i][j] );
     }
   }
   return C;
@@ -2557,7 +2557,7 @@ SGTELIB::Matrix SGTELIB::Matrix::min ( const SGTELIB::Matrix & A ,
   int i,j;
   for ( i = 0 ; i < nb_rows ; ++i ) {
     for ( j = 0 ; j < nb_cols ; ++j ){
-      C._X[i][j] = std::min( A._X[i][j] , B._X[i][j] );
+      C.X0[i][j] = std::min( A.X0[i][j] , B.X0[i][j] );
     }
   }
   return C;
@@ -2575,8 +2575,8 @@ int SGTELIB::Matrix::get_min_index (void ) {
   //   3 6
   for ( j = 0 ; j < _nbCols ; ++j ){
     for ( i = 0 ; i < _nbRows ; ++i ){
-      if (_X[i][j] < vmin){
-        vmin = _X[i][j];
+      if (X0[i][j] < vmin){
+        vmin = X0[i][j];
         kmin = k;
       }
       k++;
@@ -2592,8 +2592,8 @@ int SGTELIB::Matrix::get_min_index_row ( const int i ) {
   int j, jmin=0;
   double vmin = +SGTELIB::INF;
   for ( j = 0 ; j < _nbCols ; ++j ){
-    if (_X[i][j] < vmin){
-      vmin = _X[i][j];
+    if (X0[i][j] < vmin){
+      vmin = X0[i][j];
       jmin = j;
     }
   }
@@ -2607,8 +2607,8 @@ int SGTELIB::Matrix::get_min_index_col ( const int j ) {
   int i, imin=0;
   double vmin = +SGTELIB::INF;
   for ( i = 0 ; i < _nbRows ; ++i ){
-    if (_X[i][j] < vmin){
-      vmin = _X[i][j];
+    if (X0[i][j] < vmin){
+      vmin = X0[i][j];
       imin = i;
     }
   }
@@ -2636,10 +2636,10 @@ SGTELIB::Matrix SGTELIB::Matrix::get_distances_norm2 ( const SGTELIB::Matrix & A
       // Distance between the point ia of the cache and the point ib of the matrix XXs
       v = 0;
       for (j=0 ; j < n ; j++){
-        d = A._X[ia][j]-B._X[ib][j];
+        d = A.X0[ia][j]-B.X0[ib][j];
         v += d*d;
       }
-      D._X[ia][ib] = sqrt(v);
+      D.X0[ia][ib] = sqrt(v);
     }
   }
   return D;
@@ -2666,9 +2666,9 @@ SGTELIB::Matrix SGTELIB::Matrix::get_distances_norm1 ( const SGTELIB::Matrix & A
       // Distance between the point ia of the cache and the point ib of the matrix XXs
       v = 0;
       for (j=0 ; j < n ; j++){
-        v += fabs(A._X[ia][j]-B._X[ib][j]);
+        v += fabs(A.X0[ia][j]-B.X0[ib][j]);
       }
-      D._X[ia][ib] = v;
+      D.X0[ia][ib] = v;
     }
   }
   return D;
@@ -2695,9 +2695,9 @@ SGTELIB::Matrix SGTELIB::Matrix::get_distances_norminf ( const SGTELIB::Matrix &
       // Distance between the point ia of the cache and the point ib of the matrix XXs
       v = 0;
       for (j=0 ; j < n ; j++){
-        v = std::max( v , fabs(A._X[ia][j]-B._X[ib][j]) );
+        v = std::max( v , fabs(A.X0[ia][j]-B.X0[ib][j]) );
       }
-      D._X[ia][ib] = v;
+      D.X0[ia][ib] = v;
     }
   }
   return D;
@@ -2725,7 +2725,7 @@ int SGTELIB::Matrix::find_row (SGTELIB::Matrix & R){
   for (i=0 ; i<_nbRows ; i++){
     diff = false;    
     for (j=0 ; j<_nbCols ; j++){
-      if (_X[i][j]!=R._X[0][j]){
+      if (X0[i][j]!=R.X0[0][j]){
         diff = true;
         break;
       }
@@ -2770,7 +2770,7 @@ SGTELIB::Matrix SGTELIB::Matrix::get_poll_directions ( const SGTELIB::Matrix sca
     SGTELIB::Matrix v("v",1,N);
     for (j=0 ; j<N ; j++){
       if (domain[j]==SGTELIB::PARAM_DOMAIN_CONTINUOUS){
-        v._X[0][j] = SGTELIB::quick_norm_rand();
+        v.X0[0][j] = SGTELIB::quick_norm_rand();
       }
     }
 
@@ -2781,7 +2781,7 @@ SGTELIB::Matrix SGTELIB::Matrix::get_poll_directions ( const SGTELIB::Matrix sca
     for (i=0 ; i<N ; i++){
       if (domain[i]==SGTELIB::PARAM_DOMAIN_CONTINUOUS){
         for (j=0 ; j<N ; j++){
-          D._X[i][j] = double(i==j)-2*v[i]*v[j];
+          D.X0[i][j] = double(i==j)-2*v[i]*v[j];
         }
       }
     }
@@ -2798,29 +2798,29 @@ SGTELIB::Matrix SGTELIB::Matrix::get_poll_directions ( const SGTELIB::Matrix sca
     if (domain[i]!=SGTELIB::PARAM_DOMAIN_CONTINUOUS){
       for (j=0 ; j<N ; j++){
         if (domain[j]==SGTELIB::PARAM_DOMAIN_CONTINUOUS){
-          D._X[i][j] = 2*uniform_rand()-1;
+          D.X0[i][j] = 2*uniform_rand()-1;
         }
       }
     }
 
     // Find max asb
     d = 0;
-    for (j=0 ; j<N ; j++) d = std::max( d , fabs(D._X[i][j]) );
+    for (j=0 ; j<N ; j++) d = std::max( d , fabs(D.X0[i][j]) );
 
     // Scale continuous dimensions
     for (j=0 ; j<N ; j++){
       if (domain[j]==SGTELIB::PARAM_DOMAIN_CONTINUOUS){
-        D._X[i][j] = scaling[j]*msize*SGTELIB::rceil(rho*D._X[i][j]/d);
+        D.X0[i][j] = scaling[j]*msize*SGTELIB::rceil(rho*D.X0[i][j]/d);
       }
     }
 
     // Add extended POLL for discrete values
     if ( (domain[i]==SGTELIB::PARAM_DOMAIN_INTEGER) ||
          (domain[i]==SGTELIB::PARAM_DOMAIN_BOOL) ){
-      D._X[i][i] = (i%2==0)?-1:+1;
+      D.X0[i][i] = (i%2==0)?-1:+1;
     }
     else if (domain[i]==SGTELIB::PARAM_DOMAIN_CAT){
-      D._X[i][i] = SGTELIB::rceil(uniform_rand()*scaling[i]);
+      D.X0[i][i] = SGTELIB::rceil(uniform_rand()*scaling[i]);
     }
 
   }
@@ -2856,9 +2856,9 @@ SGTELIB::Matrix SGTELIB::Matrix::get_poll_directions ( const SGTELIB::Matrix sca
 void SGTELIB::Matrix::swap_rows(const int i1 , const int i2){
   double buffer;
   for (int j=0 ; j<_nbCols ; j++){
-    buffer    = _X[i1][j];
-    _X[i1][j] = _X[i2][j];
-    _X[i2][j] = buffer;
+    buffer    = X0[i1][j];
+    X0[i1][j] = X0[i2][j];
+    X0[i2][j] = buffer;
   }
 }//
 
@@ -2888,7 +2888,7 @@ SGTELIB::Matrix SGTELIB::Matrix::lu_inverse ( double * det ) const{
     // Find pivot
     pivot_max = -1;
     for (i=k ; i<N ; i++){
-      pivot = A._X[k][i];
+      pivot = A.X0[k][i];
       if (pivot<0) pivot*=-1;
       if (pivot>pivot_max){
         ip = i;
@@ -2904,15 +2904,15 @@ SGTELIB::Matrix SGTELIB::Matrix::lu_inverse ( double * det ) const{
 
     // Gaussian elimination
     for (j=k+1 ; j<N ; j++){
-      pivot = A._X[j][k]/A._X[k][k];
-      A._X[j][k] = pivot;
-      for (i=k+1 ; i<N ; i++) A._X[j][i] -= pivot*A._X[k][i];
+      pivot = A.X0[j][k]/A.X0[k][k];
+      A.X0[j][k] = pivot;
+      for (i=k+1 ; i<N ; i++) A.X0[j][i] -= pivot*A.X0[k][i];
     }
   }
 
   // Construct the whole matrix P (under the name Ai)
   SGTELIB::Matrix Ai ("Ai",N,N);
-  for (i=0 ; i<N; i++) Ai._X[i][P[i]] = 1;
+  for (i=0 ; i<N; i++) Ai.X0[i][P[i]] = 1;
 
 
 
@@ -2920,7 +2920,7 @@ SGTELIB::Matrix SGTELIB::Matrix::lu_inverse ( double * det ) const{
     // Compute the determinant of the matrix that is inverted
     double v = 1;
     // Compute the determinant of U
-    for (i=0 ; i<N ; i++) v *= A._X[i][i];
+    for (i=0 ; i<N ; i++) v *= A.X0[i][i];
     // Comput ethe determinant of P
     i = 0;
     while (i<N){
@@ -2943,16 +2943,16 @@ SGTELIB::Matrix SGTELIB::Matrix::lu_inverse ( double * det ) const{
     // Tri-L solve
     for (i=0 ; i<N ; i++){
       for (j=0 ; j<i ; j++){
-        y._X[i][0] -= A._X[i][j]*y._X[j][0];
+        y.X0[i][0] -= A.X0[i][j]*y.X0[j][0];
       }
     }
 
     // Tri-U solve
     for (int i=N-1 ; i>=0 ; i--){
       for (int j=i+1 ; j<N ; j++){
-        y._X[i][0] -= A._X[i][j]*y._X[j][0];
+        y.X0[i][0] -= A.X0[i][j]*y.X0[j][0];
       }
-      y._X[i][0] /= A._X[i][i];
+      y.X0[i][0] /= A.X0[i][i];
     }
 
     Ai.set_col(y,k);
